Sensors
=======

A simple and flexible way to use sensors in your projects. The sensors module
provides a set of classes to handle the most common sensors used in attitude
estimation algorithms.

The class :class:`Sensors` already includes the implementation of the most
common sensors used in attitude estimation algorithms.

.. autoclass:: ahrs.utils.sensors.Sensors
